On Tuesday 02 September 2003 23:14, [EMAIL PROTECTED] wrote:
> I was wondering if anyone has tried to build a kiosk Gentoo system?
>
> I need to build out a touchscreen system running linux which boots a
> minimal install, loads X - does an autologin and starts an application. I
> have built a RedHat box which can do this but would much rather use
> Gentoo since I like it alot and I can control what gets installed.
>
> I have gotten my Gentoo distro up and running with touch on the required
> hardware for the project but I was wondering what do I need besides Xfree
> in order to accomplish my task?
>
> I was reading about gdm which has a built in autologin feature but it
> requires GNOME or at least it tells me it does when I do the emerge. I
> used gdm on my RedHat box to get the autologin to work but it seems like
> overkill for what I'm trying to accomplish.
>
> I also looked online and found a couple good articles but they all
> refered to RedHat which I will try to garnish information from but any
> real world help would be great.

You don't need to start up xdm or others to get X running as a certain user 
with a specific app.

Use init to start X as a user and run the app by editing the /etc/inittab 
file.  Put something like the following in /etc/inittab:

x1:345:respawn:/bin/su - {USER} -c "/usr/bin/env XSESSION={APP} 
/usr/X11R6/bin/startx"
-----

APP is the binary of the app you want to run and USER is the account to run 
the app as.

Also, apply the included patch for /etc/X11/chooser.sh.
--- chooser.sh.old	2003-08-29 10:15:26.000000000 -0500
+++ chooser.sh	2003-08-29 10:28:19.000000000 -0500
@@ -4,10 +4,10 @@
 # Author:  Martin Schlemmer <[EMAIL PROTECTED]>
 # $Header: /home/cvsroot/gentoo-x86/x11-base/xfree/files/4.3.0/chooser.sh,v 1.2 2003/06/15 04:02:47 seemant Exp $
 
 # If $XSESSION is "", source first /etc/conf.d/basic, and then /etc/rc.conf
 if [ -z "${XSESSION}" ]
 then
-	[ -f /etc/conf.d/basic ] && . /etc/conf.d/basic
+	[ -f /etc/env.d/00basic ] && . /etc/env.d/00basic
 	[ -f /etc/rc.conf ] && . /etc/rc.conf
 fi
 
@@ -54,7 +54,9 @@
 		done
 
 		# If all else fail, run twm
-		GENTOO_EXEC="/usr/X11R6/bin/twm"
+		if [ -z "${GENTOO_EXEC}" ]; then
+			GENTOO_EXEC="/usr/X11R6/bin/twm"
+		fi
 	fi
 fi
 
@@ -4,10 +4,10 @@
 # $Header: /home/cvsroot/gentoo-x86/x11-base/xfree/files/4.3.0/chooser.sh,v 1.2 2003/06/15 04:02:47 seemant Exp $
 
-# If $XSESSION is "", source first /etc/conf.d/basic, and then /etc/rc.conf
+# If $XSESSION is "", source first /etc/env.d/00basic and then /etc/rc.conf
 if [ -z "${XSESSION}" ]
 then

--
[EMAIL PROTECTED] mailing list

Reply via email to